@@ -1,3 +1,4 @@
+import string
 from math import ceil
 from operator import itemgetter
 
@@ -47,9 +48,24 @@ class ModelResults:
             Original text with topic number assigned to each
 
         """
+        X = X[~X[text_column_name].isna()]
+        X = X[X[text_column_name] != ""]
+        X = X[X[text_column_name] != " "]
+        X = X[X[text_column_name] != "NA"]
+        X = X[X[text_column_name] != "n/a"]
+        X = X[X[text_column_name] != "N/A"]
+        X = X[X[text_column_name] != "na"]
+
+        all_stop_words = (
+            set(ENGLISH_STOP_WORDS)
+            | set(["-PRON-"])
+            | set(string.punctuation)
+            | set([" "])
+        )
+
         ct = CleanText()
         vectorizer = TfidfVectorizer(
-            tokenizer=ct.lematize, ngram_range=(1, 3), stop_words=ENGLISH_STOP_WORDS,
+            tokenizer=ct.lematize, ngram_range=(1, 3), stop_words=all_stop_words,
         )
         vectors = vectorizer.fit_transform(X[text_column_name]).todense()
 
@@ -64,7 +80,7 @@ class ModelResults:
             # In case 1, add 1 to get at least 2
             # The rest are based on eyeballing numbers
             min_topics = ceil(X.shape[0] * 0.01) + 1
-            max_topics = ceil(X.shape[0] * 0.4)
+            max_topics = ceil(X.shape[0] * 0.2)
             step = ceil((max_topics - min_topics) / 5)
 
             topic_nums = list(np.arange(min_topics, max_topics, step))
@@ -125,7 +141,7 @@ class ModelResults:
             np.max(component_loadings, axis=1), columns=["top_topic_loading"]
         )
 
-        X.reset_index(inplace=True, drop=True)
+        X.reset_index(inplace=True, drop=False)
         vector_df.reset_index(inplace=True, drop=True)
 
         # Fix for duplicate text_column_name
@@ -187,7 +203,10 @@ class ModelResults:
         print("Topics created with top words & example texts:")
         print(concated_topics)
 
-        return concated_topics, combined_df[[text_column_name, "top_topic_num"]]
+        return (
+            concated_topics,
+            combined_df[["index", text_column_name, "top_topic_num"]],
+        )
 
     def coefficients_summary(
         self, X, y, num_repetitions, num_coefficients, model_type, params={}
@@ -294,10 +313,15 @@ class ModelResults:
             Has groups, top words, and counts
 
         """
+        all_stop_words = (
+            set(ENGLISH_STOP_WORDS)
+            | set(["-PRON-"])
+            | set(string.punctuation)
+            | set([" "])
+        )
+
         cv = CountVectorizer(
-            stop_words=ENGLISH_STOP_WORDS,
-            ngram_range=(min_ngram, 3),
-            min_df=num_times_min,
+            stop_words=all_stop_words, ngram_range=(min_ngram, 3), min_df=num_times_min,
         )
         vectors = cv.fit_transform(X[text_col_name]).todense()
         words = cv.get_feature_names()
